import './DiscussionPage.css'
import DiscussionList from "../components/DiscussionList.tsx";
import {discussionsAPI, STUDENT_ROLE} from "../utils.ts";
import {useState} from "react";
import DiscussionPopupForm from '../components/DiscussionPopupForm.tsx';
import {useDiscussionContext} from '../contexts/DiscussionContext.tsx';
import axios from 'axios';
import {useUserContext} from "../contexts/UserContext.tsx";
import {useStudentUserContext} from "../contexts/StudentUserContext.tsx";

export default function DiscussionPage() {
    const [showPopup, setShowPopup] = useState(false);
    const {token, role} = useUserContext();
    const {student} = useStudentUserContext();

    const {refreshDiscussions, sortDiscussions} = useDiscussionContext();

    const togglePopup = () => {
        setShowPopup(!showPopup);
    };

    const handleCreate = async (formData: { title: string; content: string; lab: string }) => {
        const discussionItem = {
            title: formData.title,
            content: formData.content,
            labName: formData.lab,
            student: student,
        };

        axios.post(`${discussionsAPI}/add`, discussionItem, {
            headers: {
                'Authorization': `Bearer ${token}`,
                'Content-Type': 'application/json'
            }
        })
            .then(response => {
                console.log('Discussion created successfully:', response.data);
                refreshDiscussions(); // Refresh discussions after successful creation
            })
            .catch(error => {
                console.error('Error creating discussion:', error);
            });
        togglePopup();
    };

    const handleSortChange = (event: React.ChangeEvent<HTMLSelectElement>) => {
        sortDiscussions(event.target.value); // Sort discussions based on selected criteria
    };

    return (
        <div className='discussion-page center-content'>
            <section className='discussion-header'>
                <h1>Discussion Forum</h1>
                <div className='discussion-header-buttons'>
                    <div className='sort-dropdown'>
                        <label htmlFor="filter" className='secondary-button'>Sort by:</label>
                        <select className='secondary-button' name="filter" id="filter" onChange={handleSortChange}>
                            <option value="oldest">Date (Oldest to Newest)</option>
                            <option value="newest">Date (Newest to Oldest)</option>
                            <option value="highest">Comments (Most to Fewest)</option>
                            <option value="lowest">Comments (Fewest to Most)</option>
                        </select>
                    </div>
                    {(role === STUDENT_ROLE) && (
                        <>
                            <button className='primary-button' onClick={togglePopup}>Create Discussion</button>
                            {showPopup && <DiscussionPopupForm onClose={togglePopup} onCreate={handleCreate}/>}
                        </>
                    )}

                </div>
            </section>
            <DiscussionList/>
        </div>
    );
}