import './OpeningsPage.css'
import {openingsAPI, PROFESSOR_ROLE} from "../utils.ts";
import {useState} from "react";
import {useUserContext} from "../contexts/UserContext.tsx";
import axios from "axios";
import OpeningsPopupForm from "../components/OpeningsPopupForm.tsx";
import OpeningsList from "../components/OpeningsList.tsx";
import {useOpeningsContext} from "../contexts/OpeningsContext.tsx";
import {ProfessorUser} from "../types.ts";

export default function OpeningsPage() {

    const {refreshOpenings} = useOpeningsContext();

    const [showPopup, setShowPopup] = useState(false);
    const {token, role} = useUserContext();

    const togglePopup = () => {
        setShowPopup(!showPopup);
    };

    const handleCreate = async (formData: {
        name: string;
        description: string;
        type: string;
        url: string;
        labName: string;
        professor: ProfessorUser;
    }) => {
        console.log(formData);
        axios.post(`${openingsAPI}`, formData, {
            headers: {
                'Authorization': `Bearer ${token}`,
                'Content-Type': 'application/json'
            }
        })
            .then(response => {
                console.log('Opening created successfully:', response.data);
                refreshOpenings();
            })
            .catch(error => {
                console.error('Error creating opening:', error);
            });
        togglePopup();
    };

    return (
        <div className='openings-page center-content'>
            <section className='openings-header'>
                <h1>Current Openings</h1>
                <div className='openings-header-buttons'>
                    {(role === PROFESSOR_ROLE) && (
                        <>
                            <button className='primary-button' onClick={togglePopup}>Add Opening</button>
                            {showPopup && <OpeningsPopupForm onClose={togglePopup} onCreate={handleCreate}/>}
                        </>
                    )}

                </div>
            </section>
            <OpeningsList/>
        </div>
    );
}